@@ -154,7 +154,7 @@ static void clear_umodes(Channel *chan, int32 modes)
 	    snprintf(buf, sizeof(buf), "-%s",
 		     mode_flags_to_string(cu->mode & modes, MODE_CHANUSER));
 	    send_cmode(MODE_SENDER(s_ChanServ), chan->name, buf,
-		       cu->user->nick);
+		       cu->user->nick, cu->user->nick);
 	    cu->mode &= ~modes;
 	}
     }
