@@ -553,7 +553,7 @@ static void do_send(User *u)
 	    if (ni->flags & NI_MEMO_RECEIVE) {
 		if (MSNotifyAll) {
 		    for (u = firstuser(); u; u = nextuser()) {
-			if (u->ni == ni) {
+			if (u->ni==ni && (u->real_ni->status & NS_RECOGNIZED)){
 			    notice_lang(s_MemoServ, u, MEMO_NEW_MEMO_ARRIVED,
 					source, s_MemoServ, m->number);
 			}
