@@ -1,6 +1,6 @@
 /* Definitions of IRC message functions and list of messages.
  *
- * IRC Services is copyright (c) 1996-2001 Andrew Church.
+ * IRC Services is copyright (c) 1996-2002 Andrew Church.
  *     E-mail: <achurch@achurch.org>
  * Parts copyright (c) 1999-2000 Andrew Kempe and others.
  * This program is free but copyrighted software; see the file COPYING for
@@ -412,7 +412,7 @@ static void m_time(char *source, int ac, char **av)
     time(&t);
     tm = localtime(&t);
     strftime(buf, sizeof(buf), "%a %b %d %H:%M:%S %Y %Z", tm);
-    send_cmd(NULL, "391 :%s", buf);
+    send_cmd(NULL, "391 %s %s :%s", source, ServerName, buf);
 }
 
 /*************************************************************************/
@@ -551,6 +551,10 @@ static void m_setident(char *source, int ac, char **av)
     free(u->username);
     u->username = sstrdup(av[0]);
 }
+static void m_chgident(char *source, int ac, char **av) {
+    if (ac == 2)
+	m_setident(av[0], ac-1, av+1);
+}
 
 
 static void m_sethost(char *source, int ac, char **av)
@@ -567,6 +571,10 @@ static void m_sethost(char *source, int ac, char **av)
     free(u->fakehost);
     u->fakehost = sstrdup(av[0]);
 }
+static void m_chghost(char *source, int ac, char **av) {
+    if (ac == 2)
+	m_sethost(av[0], ac-1, av+1);
+}
 
 
 static void m_setname(char *source, int ac, char **av)
@@ -583,6 +591,10 @@ static void m_setname(char *source, int ac, char **av)
     free(u->realname);
     u->realname = sstrdup(av[0]);
 }
+static void m_chgname(char *source, int ac, char **av) {
+    if (ac == 2)
+	m_setname(av[0], ac-1, av+1);
+}
 
 #endif	/* IRC_UNREAL */
 
@@ -594,7 +606,7 @@ Message messages[] = {
     { "401",       NULL },
     { "436",       m_nickcoll },
     { "AWAY",      m_away },
-    { "INFO",	   m_info },
+    { "INFO",      m_info },
     { "JOIN",      m_join },
     { "KICK",      m_kick },
     { "KILL",      m_kill },
@@ -636,12 +648,12 @@ Message messages[] = {
 #endif
 
 #ifdef IRC_BAHAMUT
-    { "CAPAB",	   NULL },
+    { "CAPAB",     NULL },
     { "SVINFO",    NULL },
 #endif
 
 #if defined(IRC_BAHAMUT) || defined(IRC_UNREAL)
-    { "SJOIN",	   m_sjoin },
+    { "SJOIN",     m_sjoin },
 #endif
 
 #ifdef IRC_UNREAL
@@ -649,6 +661,10 @@ Message messages[] = {
     { "SETIDENT",  m_setident },
     { "SETHOST",   m_sethost },
     { "SETNAME",   m_setname },
+    { "CHGIDENT",  m_chgident },
+    { "CHGHOST",   m_chghost },
+    { "CHGNAME",   m_chgname },
+    { "TKL",       m_tkl },
 #endif
 
     { NULL }
