@@ -1,6 +1,6 @@
 /* Routines for handling mode flags and strings.
  *
- * IRC Services is copyright (c) 1996-2001 Andrew Church.
+ * IRC Services is copyright (c) 1996-2002 Andrew Church.
  *     E-mail: <achurch@achurch.org>
  * Parts copyright (c) 1999-2000 Andrew Kempe and others.
  * This program is free but copyrighted software; see the file COPYING for
@@ -74,6 +74,9 @@ static const struct flag cmodes[] = {
     { 'G', CMODE_G },
     { 'u', CMODE_u },
     { 'f', CMODE_f },
+#endif
+#ifdef IRC_BAHAMUT
+    { 'M', CMODE_M },
 #endif
     { 0, 0 }
 };
