@@ -1,6 +1,6 @@
 /* Routines to maintain a list of online users.
  *
- * IRC Services is copyright (c) 1996-2001 Andrew Church.
+ * IRC Services is copyright (c) 1996-2002 Andrew Church.
  *     E-mail: <achurch@achurch.org>
  * Parts copyright (c) 1999-2000 Andrew Kempe and others.
  * This program is free but copyrighted software; see the file COPYING for
@@ -413,7 +413,8 @@ int do_nick(const char *source, int ac, char **av)
 #endif
 
 #ifdef STATISTICS
-	user->server->stats->usercnt++;
+	if (user->server)
+	    user->server->stats->usercnt++;
 #endif
 	display_news(user, NEWS_LOGON);
 
@@ -804,13 +805,15 @@ void do_umode(const char *source, int ac, char **av)
 		display_news(user, NEWS_OPER);
 		opcnt++;
 #ifdef STATISTICS
-		user->server->stats->opercnt++;
+		if (user->server)
+		    user->server->stats->opercnt++;
 #endif
 	    } else {
 		user->mode &= ~UMODE_o;
 		opcnt--;
 #ifdef STATISTICS
-		user->server->stats->opercnt--;
+		if (user->server)
+		    user->server->stats->opercnt--;
 #endif
 	    }
 	    break;
@@ -1040,8 +1043,8 @@ char *create_mask(User *u, int use_fakehost)
      */
     end = mask = smalloc(strlen(u->username) + strlen(host) + 2);
     end += sprintf(end, "%s@", u->username);
-    if (strspn(u->host, "0123456789.") == strlen(host)
-		&& (s = strchr(u->host, '.'))
+    if (strspn(host, "0123456789.") == strlen(host)
+		&& (s = strchr(host, '.'))
 		&& (s = strchr(s+1, '.'))
 		&& (s = strchr(s+1, '.'))
 		&& (   !strchr(s+1, '.'))) {	/* IP addr */
